@@ -490,8 +490,8 @@ class DataTransformerForm(BaseInlineFormSet):
         super(DataTransformerForm, self).add_fields(form, index)
         dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self,
                                                              fk_name='parent',
-                                                             extra=1, exclude=['updated_at', 'created_at'],
-                                                             form=DataTransform)
+                                                             extra=1, exclude=['updated_at', 'created_at']
+                                                             )
         form.nested_data_transformer_form = dataTransformerInlineFormset(
             instance=form.instance,
             data=form.data if form.is_bound else None,
@@ -517,7 +517,6 @@ class DataTransformerForm(BaseInlineFormSet):
             extra=1)
 
     def as_p(self):
-        super(DataTransformerForm, self).as_p()
         forms = ' '.join(' '.join([form.as_p(),form.nested_data_transformer_form,form.nested_constants_form,form.nested_hardware_outputs_form,form.nested_hardware_stats_form]) for form in self)
         return mark_safe(str(self.management_form) + '\n' + forms)
 
